@@ -2,59 +2,63 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 
-"""openstef custom exceptions
-"""
-from datetime import datetime
-
-
+"""Openstef custom exceptions."""
 # Define custom exception
 class NoPredictedLoadError(Exception):
-    """No predicted load for given datatime range"""
+    """No predicted load for given datatime range."""
 
     def __init__(
         self,
         pid: int,
         message: str = "No predicted load found",
-    ) -> Exception:
+    ):
         self.pid = pid
         self.message = message
         super().__init__(self.message)
 
 
 class NoRealisedLoadError(Exception):
-    """No realised load for given datetime range"""
+    """No realised load for given datetime range."""
 
     def __init__(
         self,
         pid: int,
         message: str = "No realised load found",
-    ) -> Exception:
+    ):
         self.pid = pid
         self.message = message
         super().__init__(self.message)
 
 
 class InputDataInvalidError(Exception):
-    """Invalid input data"""
+    """Invalid input data."""
 
 
 class InputDataInsufficientError(InputDataInvalidError):
-    """Insufficient input data"""
+    """Insufficient input data."""
 
 
 class InputDataWrongColumnOrderError(InputDataInvalidError):
-    """Wrong column order input data"""
+    """Wrong column order input data."""
 
 
 class OldModelHigherScoreError(Exception):
-    """Old model has a higher score then new model"""
+    """Old model has a higher score then new model."""
 
 
 class ModelWithoutStDev(Exception):
-    """A machine learning model should have a valid standard deviation"""
+    """A machine learning model should have a valid standard deviation."""
 
 
 class ComponentForecastTooShortHorizonError(Exception):
-    """Component forecasts should be available for at least 30 hours in advance"""
+    """Component forecasts should be available for at least 30 hours in advance."""
 
-    pass
+
+class PredictionJobException(Exception):
+    """One or more prediction jobs raised an exception."""
+
+    def __init__(self, metrics=None):
+        super().__init__("One or more prediction jobs raised an exception.")
+        if metrics is None:
+            metrics = {}
+        self.metrics = metrics
