@@ -1,8 +1,12 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+"""This module defines several FeatureApplicators.
+
+These applicatiors are used to add features to the input data in the corresponding pipelines.
+
+"""
 from abc import ABC, abstractmethod
-from turtle import st
 from typing import List, Optional, Union
 
 import numpy as np
@@ -24,6 +28,8 @@ LATENCY_CONFIG = {"APX": 24}  # A specific latency is part of a specific feature
 
 
 class AbstractFeatureApplicator(ABC):
+    """Defines the Applicator interface."""
+
     def __init__(
         self,
         horizons: Union[List[float], str],
@@ -33,8 +39,10 @@ class AbstractFeatureApplicator(ABC):
         """Initialize abstract feature applicator.
 
         Args:
-            horizons (list): list of horizons in hours
-            feature_names (List[str]):  List of requested features
+            horizons: list of horizons in hours
+            feature_names:  List of requested features
+            feature_modules: List of modules from which FeatureAdders should be loaded.
+
         """
         if not isinstance(horizons, str) and type(horizons) is not list and not None:
             raise ValueError("horizons must be added as a list")
@@ -48,19 +56,27 @@ class AbstractFeatureApplicator(ABC):
     def add_features(
         self, df: pd.DataFrame, pj: PredictionJobDataClass = None
     ) -> pd.DataFrame:
-        """Adds features to an input DataFrame
+        """Adds features to an input DataFrame.
 
         Args:
-            df: pd.DataFrame with input data to which the features have to be added
+            df: DataFrame with input data to which the features have to be added
             pj: (Optional) A prediction job that is needed for location dependent features,
                 if not specified a default location is used
+
+        Returns:
+            Dataframe with added features.
+
         """
-        pass
 
 
 class TrainFeatureApplicator(AbstractFeatureApplicator):
+    """Feature applicator for use during training."""
+
     def add_features(
-        self, df: pd.DataFrame, pj: PredictionJobDataClass = None, latency_config=None
+        self,
+        df: pd.DataFrame,
+        pj: PredictionJobDataClass = None,
+        latency_config: dict = None,
     ) -> pd.DataFrame:
         """Adds features to an input DataFrame.
 
@@ -73,18 +89,17 @@ class TrainFeatureApplicator(AbstractFeatureApplicator):
             0.25 hours this feature is added as in this case the feature is available.
 
         Args:
-            df (pd.DataFrame):  Input data to which the features will be added.
+            df: Input data to which the features will be added.
             pj: (Optional) A prediction job that is needed for location dependent features,
                 if not specified a default location is used
-            latency_config (dict): Optional. Invalidate certain features that are not
-                available for a specific horizon due to data latency. Default to
-                {"APX": 24}
+            latency_config: (Optional) Invalidate certain features that are not
+                available for a specific horizon due to data latency. Defaults to
+                ``{"APX": 24}``.
 
         Returns:
-            pd.DataFrame: Input DataFrame with an extra column for every added feature
-                and sorted on the datetime index.
-        """
+            Input DataFrame with an extra column for every added feature and sorted on the datetime index.
 
+        """
         # If pj is none add empty dict
         if pj is None:
             pj = {}
@@ -146,23 +161,23 @@ class TrainFeatureApplicator(AbstractFeatureApplicator):
 
 
 class OperationalPredictFeatureApplicator(AbstractFeatureApplicator):
+    """Feature applicator for use in operational forecasts."""
+
     def add_features(
         self, df: pd.DataFrame, pj: PredictionJobDataClass = None
     ) -> pd.DataFrame:
         """Adds features to an input DataFrame.
 
-        This method is implemented specifically for an operational prediction pipeline
-         and will add every available feature.
+        This method is implemented specifically for an operational prediction pipeline and will add every available feature.
 
         Args:
-            df: pd.DataFrame with input data to which the features have to be added
+            df: DataFrame with input data to which the features have to be added
             pj: (Optional) A prediction job that is needed for location dependent features,
                 if not specified a default location is used
         Returns:
-            pd.DataFrame: Input DataFrame with an extra column for every added feature.
+           Input DataFrame with an extra column for every added feature.
 
         """
-
         # If pj is none add empty dict
         if pj is None:
             pj = {}
